
%set the parameter values:
beta=.58;
gam=.99;
alpha=.6;

%steady state capital stock
k=alpha*beta/(1-alpha+alpha*beta);

%verify that the steady state formula is correct:
[v] = Euler([alpha gam beta],[k k k]);

%compute coefficients in Taylor series expansion of Euler equation:
[tsecoef] = tsemat('Euler',[alpha gam beta],[k k k]);

%log-linearized Euler equation: alpha_0*khat(t+2) + alpha_1*khat(t+1) + alpha_2*khat(t+2) = 0
alpha_0=tsecoef(3)*k;
alpha_1=tsecoef(2)*k;
alpha_2=tsecoef(1)*k;

%compute the roots of the log-linearized Euler equation:
c=[alpha_0 alpha_1 alpha_2];
rt=roots(c)
disp('roots')
rt

k1=.999;
k2=.001;

[k1,k2] = findcycle(k1,k2,alpha,gam,beta)

[v1] = Euler([alpha gam beta],[k1 k2 k1]);
[v2] = Euler([alpha gam beta],[k2 k1 k2]);

sprintf('roots of Euler equation = %7.4f, %7.4f, k = %7.4f, k1 = %7.4f, k2 = %7.4f',rt,k,k1,k2)
sprintf('beta = %7.4f, gam = %7.4f, alpha = %7.4f',beta,gam,alpha)



